@@ -65,9 +65,16 @@
 
 /* New profile guessing API */
 
-static GList *profiles = NULL;
+#define GUPNP_DLNA_DEBUG_ENV "GUPNP_DLNA_DEBUG"
 
-static gboolean is_video_profile (GstEncodingProfile *profile)
+#define gupnp_dlna_debug(args...)                               \
+do {                                                            \
+        const gchar *_e = g_getenv (GUPNP_DLNA_DEBUG_ENV);      \
+        if (_e && !g_str_equal (_e, "0"))                       \
+                g_debug (args);                                 \
+} while (0)
+
+static gboolean is_video_profile (const GstEncodingProfile *profile)
 {
         GList *i;
 
@@ -106,8 +113,10 @@ static gboolean structure_is_subset (const GstStructure *st1,
         for (i = 0; i < gst_structure_n_fields (st2); i++) {
                 const gchar *name = gst_structure_nth_field_name (st2, i);
 
-                if (!gst_structure_has_field(st1, name))
+                if (!gst_structure_has_field(st1, name)) {
+                        gupnp_dlna_debug ("    missing field %s", name);
                         return FALSE;
+                }
         }
 
         return TRUE;
@@ -141,9 +150,9 @@ static gboolean caps_can_intersect_and_is_subset (GstCaps *stream_caps,
 }
 
 static gboolean
-match_profile (GstEncodingProfile     *profile,
-               GstCaps                *caps,
-               GstEncodingProfileType type)
+match_profile (const GstEncodingProfile *profile,
+               GstCaps                  *caps,
+               GstEncodingProfileType    type)
 {
         GList *i;
 
@@ -165,7 +174,8 @@ match_profile (GstEncodingProfile     *profile,
 }
 
 static gboolean
-check_container (GstDiscovererInformation *info, GstEncodingProfile *profile)
+check_container (GstDiscovererInformation *info,
+                const GstEncodingProfile  *profile)
 {
         /* Top-level GstStreamInformation in the topology will be
          * the container */
@@ -204,7 +214,7 @@ caps_from_audio_stream_info (GstStreamAudioInformation *audio)
 }
 
 static gboolean
-check_audio_profile (GstEncodingProfile       *profile,
+check_audio_profile (const GstEncodingProfile *profile,
                      GstDiscovererInformation *info)
 {
         GstCaps *caps;
@@ -237,17 +247,30 @@ check_audio_profile (GstEncodingProfile       *profile,
 }
 
 static void
-guess_audio_profile (GstDiscovererInformation *info, gchar **name, gchar **mime)
+guess_audio_profile (GstDiscovererInformation *info,
+                     gchar                   **name,
+                     gchar                   **mime,
+                     GList                    *profiles)
 {
         GList *i;
+        GUPnPDLNAProfile *profile;
+        const GstEncodingProfile *enc_profile;
 
         for (i = profiles; i; i = i->next) {
-                GUPnPDLNAProfile *profile = (GUPnPDLNAProfile *)(i->data);
+                profile = (GUPnPDLNAProfile *)(i->data);
+                enc_profile = gupnp_dlna_profile_get_encoding_profile (profile);
 
-                if (check_audio_profile (profile->enc_profile, info) &&
-                    check_container (info, profile->enc_profile)) {
-                        *name = g_strdup (profile->name);
-                        *mime = g_strdup (profile->mime);
+                gupnp_dlna_debug ("Checking DLNA profile %s",
+                                        gupnp_dlna_profile_get_name (profile));
+                if (!check_audio_profile (enc_profile, info))
+                        gupnp_dlna_debug ("  Audio did not match");
+                else if (!check_container (info, enc_profile))
+                        gupnp_dlna_debug ("  Container did not match");
+                else {
+                        *name = g_strdup (
+                                        gupnp_dlna_profile_get_name (profile));
+                        *mime = g_strdup (
+                                        gupnp_dlna_profile_get_mime (profile));
                         break;
                 }
         }
@@ -280,6 +303,9 @@ caps_from_video_stream_info (GstStreamVideoInformation *video)
                 gst_caps_set_simple (caps, "pixel-aspect-ratio",
                                 GST_TYPE_FRACTION, n, d, NULL);
         }
+        if (video->interlaced)
+                gst_caps_set_simple (caps, "interlaced", G_TYPE_BOOLEAN,
+                                video->interlaced, NULL);
         if (video->format != GST_VIDEO_FORMAT_UNKNOWN)
                 gst_caps_set_simple (caps, "format", GST_TYPE_FOURCC,
                                 gst_video_format_to_fourcc (video->format),
@@ -299,7 +325,7 @@ caps_from_video_stream_info (GstStreamVideoInformation *video)
 }
 
 static gboolean
-check_video_profile (GstEncodingProfile *profile,
+check_video_profile (const GstEncodingProfile *profile,
                      GstDiscovererInformation *info)
 {
         GList *i;
@@ -322,6 +348,8 @@ check_video_profile (GstEncodingProfile *profile,
                                            caps,
                                            GST_ENCODING_PROFILE_VIDEO))
                                 found_video = TRUE;
+                        else
+                                gupnp_dlna_debug ("  Video did not match");
                 } else if (!found_audio &&
                            stream->streamtype == GST_STREAM_AUDIO) {
                         caps = caps_from_audio_stream_info (
@@ -330,6 +358,8 @@ check_video_profile (GstEncodingProfile *profile,
                                            caps,
                                            GST_ENCODING_PROFILE_AUDIO))
                                 found_audio = TRUE;
+                        else
+                                gupnp_dlna_debug ("  Audio did not match");
                 }
 
                 if (caps)
@@ -340,36 +370,52 @@ check_video_profile (GstEncodingProfile *profile,
                 return FALSE;
 
         /* Check container restrictions */
-        if (!check_container (info, profile))
+        if (!check_container (info, profile)) {
+                gupnp_dlna_debug ("  Container did not match");
                 return FALSE;
+        }
 
         return TRUE;
 }
 
 static void
-guess_video_profile (GstDiscovererInformation *info, gchar **name, gchar **mime)
+guess_video_profile (GstDiscovererInformation *info,
+                     gchar                   **name,
+                     gchar                   **mime,
+                     GList                    *profiles)
 {
         GUPnPDLNAProfile *profile = NULL;
+        const GstEncodingProfile *enc_profile;
         GList *i;
 
         for (i = profiles; i; i = i->next) {
                 profile = (GUPnPDLNAProfile *)(i->data);
+                enc_profile = gupnp_dlna_profile_get_encoding_profile (profile);
 
-                if (check_video_profile (profile->enc_profile, info)) {
-                        *name = g_strdup (profile->name);
-                        *mime = g_strdup (profile->mime);
+                gupnp_dlna_debug ("Checking DLNA profile %s",
+                                        gupnp_dlna_profile_get_name (profile));
+                if (check_video_profile (enc_profile, info)) {
+                        *name = g_strdup (
+                                        gupnp_dlna_profile_get_name (profile));
+                        *mime = g_strdup (
+                                        gupnp_dlna_profile_get_mime (profile));
                         break;
                 }
         }
 }
 
 static void
-guess_image_profile (GstStreamInformation *info, gchar **name, gchar **mime)
+guess_image_profile (GstStreamInformation *info,
+                     gchar               **name,
+                     gchar               **mime,
+                     GList                *profiles)
 {
         GstStreamVideoInformation *video = GST_STREAM_VIDEO_INFORMATION (info);
         GstCaps *caps;
         GList *i;
         gboolean found = FALSE;
+        GUPnPDLNAProfile *profile;
+        const GstEncodingProfile *enc_profile;
 
         if (!info || info->streamtype != GST_STREAM_IMAGE)
                 return;
@@ -377,18 +423,21 @@ guess_image_profile (GstStreamInformation *info, gchar **name, gchar **mime)
         caps = caps_from_video_stream_info (video);
 
         for (i = profiles; !found && i; i = i->next) {
-                GUPnPDLNAProfile *profile = (GUPnPDLNAProfile *)(i->data);
+                profile = (GUPnPDLNAProfile *)(i->data);
+                enc_profile = gupnp_dlna_profile_get_encoding_profile (profile);
 
                 /* Optimisation TODO: this can be pre-computed */
-                if (is_video_profile (profile->enc_profile))
+                if (is_video_profile (enc_profile))
                         continue;
 
-                if (match_profile (profile->enc_profile,
+                if (match_profile (enc_profile,
                                    caps,
                                    GST_ENCODING_PROFILE_IMAGE)) {
                         /* Found a match */
-                        *name = g_strdup (profile->name);
-                        *mime = g_strdup (profile->mime);
+                        *name = g_strdup (
+                                        gupnp_dlna_profile_get_name (profile));
+                        *mime = g_strdup (
+                                        gupnp_dlna_profile_get_mime (profile));
                         break;
                 }
         }
@@ -397,18 +446,14 @@ guess_image_profile (GstStreamInformation *info, gchar **name, gchar **mime)
 }
 
 GUPnPDLNAInformation *
-gupnp_dlna_information_new_from_discoverer_info (GstDiscovererInformation * info)
+gupnp_dlna_information_new_from_discoverer_info (GstDiscovererInformation *info,
+                                                 GList                    *profiles)
 {
         GUPnPDLNAInformation *dlna;
         GstStreamType type = GST_STREAM_UNKNOWN;
         GList *tmp = info->stream_list;
         gchar *name = NULL, *mime = NULL;
 
-        if (!profiles) {
-                profiles = g_list_concat (profiles,
-                                        gupnp_dlna_load_profiles_from_disk ());
-        }
-
         while (tmp) {
                 GstStreamInformation *stream_info =
                         (GstStreamInformation *) tmp->data;
@@ -425,12 +470,12 @@ gupnp_dlna_information_new_from_discoverer_info (GstDiscovererInformation * info
         }
 
         if (type == GST_STREAM_AUDIO)
-                guess_audio_profile (info, &name, &mime);
+                guess_audio_profile (info, &name, &mime, profiles);
         else if (type == GST_STREAM_VIDEO)
-                guess_video_profile (info, &name, &mime);
+                guess_video_profile (info, &name, &mime, profiles);
         else if (type == GST_STREAM_IMAGE)
                 /* There will be only one GstStreamInformation for images */
-                guess_image_profile (info->stream_info, &name, &mime);
+                guess_image_profile (info->stream_info, &name, &mime, profiles);
 
         dlna = gupnp_dlna_information_new (name, mime, info);
 
@@ -438,25 +483,3 @@ gupnp_dlna_information_new_from_discoverer_info (GstDiscovererInformation * info
         g_free (mime);
         return dlna;
 }
-
-GUPnPDLNAProfile *
-gupnp_dlna_profile_from_name (const gchar *name)
-{
-        GList *i;
-
-        if (!profiles) {
-                profiles = g_list_concat (profiles,
-                                        gupnp_dlna_load_profiles_from_disk ());
-        }
-
-        for (i = profiles; i != NULL; i = i->next) {
-                GUPnPDLNAProfile *profile = (GUPnPDLNAProfile *) i->data;
-
-                if (g_str_equal (profile->name, name)) {
-                        g_object_ref (profile);
-                        return profile;
-                }
-        }
-
-        return NULL;
-}
